<?php

/**
 * @file
 * Contains \Drupal\cdek_api\Form\SettingsForm.
 */

namespace Drupal\cdek_api\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\ConfigFormBase;

/**
 * CDEK API basic settings form.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cdek_api_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'cdek_api.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Get module config.
    $config = $this->config('cdek_api.settings');

    // Base path for integration API.
    $form['integration_base_path'] = [
      '#type' => 'url',
      '#title' => $this->t('Integration API base path'),
      '#default_value' => $config->get('integration_base_path'),
      '#size' => 60,
      '#required' => TRUE,
    ];
    // Base path for API.
    $form['base_path'] = [
      '#type' => 'url',
      '#title' => $this->t('API base path'),
      '#default_value' => $config->get('base_path'),
      '#size' => 60,
      '#required' => TRUE,
    ];

    // Login for API requests with authorization.
    $form['auth_login'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Login for API requests (Account)'),
      '#default_value' => $config->get('auth_login'),
      '#size' => 60,
    ];
    // Password for API requests with authorization.
    $form['secure_password'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Password for API requests (Secure password)'),
      '#default_value' => $config->get('secure_password'),
      '#size' => 60,
    ];

    // Sender city ID.
    $form['sender_city_id'] = [
      '#type' => 'number',
      '#title' => $this->t('Default sender city ID'),
      '#description' => $this->t('Integer, origin city code in accordance with city codes provided by CDEK.'),
      '#min' => 1,
      '#step' => 1,
      '#default_value' => $config->get('sender_city_id'),
    ];
    // Sender city postcode.
    $form['sender_city_postcode'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Default sender city postcode'),
      '#description' => $this->t('Integer, 6 symbols, zip code of the city of origin.'),
      '#default_value' => $config->get('sender_city_postcode'),
      '#maxlength' => 6,
      '#size' => 20,
    ];

    // Tariff ID value.
    $form['tariff_id'] = [
      '#type' => 'number',
      '#title' => $this->t('Default tariff ID'),
      '#description' => $this->t('Integer, code of chosen tariff. Should be chosen from the list provided by CDEK.'),
      '#default_value' => $config->get('tariff_id'),
      '#min' => 1,
      '#step' => 1,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Get module config.
    $config = $this->config('cdek_api.settings');

    // Set config values.
    $config->set('integration_base_path', $form_state->getValue('integration_base_path'));
    $config->set('base_path', $form_state->getValue('base_path'));
    $config->set('auth_login', trim((string) $form_state->getValue('auth_login')));
    $config->set('secure_password', trim((string) $form_state->getValue('secure_password')));
    $config->set('sender_city_id', $form_state->getValue('sender_city_id'));
    $config->set('sender_city_postcode', $form_state->getValue('sender_city_postcode'));
    $config->set('tariff_id', $form_state->getValue('tariff_id'));

    // Save module config.
    $config->save();
    parent::submitForm($form, $form_state);
  }

}
